@@ -23,6 +23,7 @@ from selenium.webdriver.remote.command import Command as RemoteCommand
 from selenium.webdriver.remote.remote_connection import RemoteConnection
 
 from appium.common.logger import logger
+from appium.webdriver.command_method import CommandMethod
 from appium.webdriver.common.mobileby import MobileBy
 
 from .appium_connection import AppiumConnection
@@ -356,6 +357,96 @@ class WebDriver(
 
         return MobileSwitchTo(self)
 
+    def add_command(self, method: CommandMethod, url: str, name: str) -> T:
+        """Add a custom command as 'name'
+
+        Args:
+            method: The method of HTTP request. Available methods are CommandMethod.
+            url: The url is URL template as https://www.w3.org/TR/webdriver/#endpoints.
+                 `$sessionId` is a placeholder of current session id.
+                 Other placeholders can be specified with `$` prefix like `$id`.
+                 Then, `{'id': 'some id'}` argument in `execute_custom_command` replaces
+                 the `$id` with the value, `some id`, in the request.
+            name: The name of a command to call in `execute_custom_command`.
+
+        Returns:
+            `appium.webdriver.webdriver.WebDriver`: Self instance
+
+        Raises:
+            ValueError
+
+        Examples:
+            Define 'test_command' as GET and 'session/$sessionId/path/to/custom/url'
+
+            >>> from appium.webdriver.command_method import CommandMethod
+            >>> driver.add_command(
+                    method=CommandMethod.GET,
+                    url='session/$sessionId/path/to/custom/url',
+                    name='test_command'
+                )
+
+        """
+        if name in self.command_executor._commands:
+            raise ValueError("{} is already defined".format(name))
+
+        if not isinstance(method, CommandMethod):
+            raise ValueError(
+                "'{}' is invalid. Valid method should be one of '{}'.".format(method, CommandMethod.__name__)
+            )
+
+        self.command_executor._commands[name] = (method.value, url)
+        return self
+
+    def execute_custom_command(self, name: str, args: Dict = {}) -> Any:
+        """Execute a custom command defined as 'name' with args command.
+
+        Args:
+            name: The name of command defined by `add_command`.
+            args: The argument as this command body
+
+        Returns:
+            'value' JSON object field in the response body.
+
+        Raises:
+            ValueError, selenium.common.exceptions.WebDriverException
+
+        Examples:
+            Calls 'test_command' command without arguments.
+
+            >>> from appium.webdriver.command_method import CommandMethod
+            >>> driver.add_command(
+                    method=CommandMethod.GET,
+                    url='session/$sessionId/path/to/custom/url',
+                    name='test_command'
+                )
+            >>> result = driver.execute_custom_command('test_command')
+
+            Calls 'test_command' command with arguments.
+
+            >>> from appium.webdriver.command_method import CommandMethod
+            >>> driver.add_command(
+                    method=CommandMethod.POST,
+                    url='session/$sessionId/path/to/custom/url',
+                    name='test_command'
+                )
+            >>> result = driver.execute_custom_command('test_command', {'dummy': 'test argument'})
+
+            Calls 'test_command' command with arguments, and the path has 'element id'.
+            The '$id' will be 'element id' by 'id' key in the given argument.
+
+            >>> from appium.webdriver.command_method import CommandMethod
+            >>> driver.add_command(
+                    method=CommandMethod.POST,
+                    url='session/$sessionId/path/to/$id/url',
+                    name='test_command'
+                )
+            >>> result = driver.execute_custom_command('test_command', {'id': 'element id', 'dummy': 'test argument'})
+
+        """
+        if name not in self.command_executor._commands:
+            raise ValueError("No {} custom command. Please add it by 'add_command'".format(name))
+        return self.execute(name, args)['value']
+
     # pylint: disable=protected-access
 
     def _addCommands(self) -> None:
